Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GenerateMAC ¶
GenerateMAC returns a byte slice that is derived from the channel's mac and a file name
Types ¶
type Adapter ¶
type Adapter interface {
GetFileSystem() config.FileSystem
SendToPeer(*protos.SignedRKSyncMessage, *common.NetworkMember)
Lookup(common.PKIidType) *common.NetworkMember
Sign(*protos.RKSyncMessage) (*protos.SignedRKSyncMessage, error)
GetMembership() []common.NetworkMember
IsMemberInChan(common.NetworkMember) bool
Accept(acceptor common.MessageAcceptor, mac []byte, passThrough bool) (<-chan *protos.RKSyncMessage, <-chan protos.ReceivedMessage)
}
Adapter enables the fsync to communicate with rksync channel
type FileSyncProvier ¶
type FileSyncProvier struct {
Adapter
// contains filtered or unexported fields
}
FileSyncProvier is the file synchronization handler
type PayloadBuffer ¶
type PayloadBuffer interface {
Push(payload *protos.Payload)
Next() int64
Expire(delta int64)
Peek() *protos.Payload
Reset(delta int64)
Size() int
Ready() chan struct{}
Close()
}
PayloadBuffer is used to store payloads into which used to support payloads with file blocks reordering according to the sequence number.
func NewPayloadBuffer ¶
func NewPayloadBuffer(next int64) PayloadBuffer
NewPayloadBuffer is factory function to create new payloads buffer
Click to show internal directories.
Click to hide internal directories.